==============
Biblion README
==============

.. image:: https://badges.gitter.im/Join%20Chat.svg
   :alt: Join the chat at https://gitter.im/pinax/biblion
   :target: https://gitter.im/pinax/biblion?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge



.. image:: https://img.shields.io/travis/pinax/biblion.svg
    :target: https://travis-ci.org/pinax/biblion

.. image:: https://img.shields.io/coveralls/pinax/biblion.svg
    :target: https://coveralls.io/r/pinax/biblion

.. image:: https://img.shields.io/pypi/dm/biblion.svg
    :target:  https://pypi.python.org/pypi/biblion/

.. image:: https://img.shields.io/pypi/v/biblion.svg
    :target:  https://pypi.python.org/pypi/biblion/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/biblion/



Biblion was the eldarion.com blog which we've extracted and open sourced.


Current features include:

 * support for multiple channels (e.g. technical vs business)
 * use of Creole and Markdown as markup format
 * Atom and RSS feeds
 * previewing of blog posts before publishing
 * optional ability to announce new posts on twitter
 * Traditional date based urls or simpler slug-only urls, via configuration
 * Control over opengraph and twitter card meta data per post
 * Review comments per post for multi-author workflows

